#
# spec file for package rendercheck
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rendercheck
Version:        1.6
Release:        1.3
Summary:        Program to test a Render extension implementation
License:        HPND
Group:          System/X11/Utilities
URL:            http://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/archive/individual/test/%{name}-%{version}.tar.xz
BuildRequires:  meson
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xrender)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
rendercheck is a program to test a Render extension implementation
against separate calculations of expected output.

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README
%{_bindir}/rendercheck
%{_mandir}/man1/rendercheck.1%{?ext_man}

%changelog
* Tue Apr 23 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to release 1.6
  * Skip shmblend if SHM pixmaps aren't supported
  * triangles: Fix tests for conjoint and disjoint ops
  * Be valgrind-clean
  * Don't fail to find the a8r8g8b8 format pointlessly
  * Enable a few more formats
  * Update bug tracker URL in man page
  * gitlab CI: add a basic build test
  * t_repeat.c, t_triangles.c: convert from ISO-8859-1 to UTF-8
  * autogen.sh: use quoted string variables
  * Start using stdbool.h instead of Xlib or custom bools.
  * Save the list of active formats in a global for use by tests.
  * Use ELF sections to make test setup easier.
  * shmblend: New test for XRenderComposite() from a pixmap in SHM.
  * autogen: Set a default prefix for patches if unset.
  * Fix a printf format warning.
  * Add a meson build system.
  * Remove the autotools build system.
  * Simplify manpage variable substitution for Meson.
  * Explain how to build using meson in the README.
  * darwin: Build fix
  * Mark pointers to test structs as used to prevent dead symbol stripping
  * Prevent ASan from placing guards around test structs as we expect them to be laid out sequentially
  * Revert "Reduce the number of colors to speed up test execution."
  * meson: Set project version
  * meson: Set project license
  * autogen.sh: drop --enable-maintainer-mode
  * autogen.sh: honor NOCONFIGURE=1
  * Fix errx handling of va_list
- switched to meson build
- fixed source URL in specfile
* Fri Jun 12 2015 sndirsch@suse.com
- Update to release 1.5
  With his gradient fixes in Dave Airlie thought it could do with a
  release, since there was a bunch of other changes.
* Thu Feb  6 2014 sndirsch@suse.com
- fixed license to HPND in specfile
* Fri Apr 13 2012 vuntz@opensuse.org
- Split rendercheck from xorg-x11. Initial version: 1.4.
